@@ -1,24 +1,26 @@
-#![deny(warnings)]
+#![deny(clippy::all, clippy::pedantic, warnings)]
 
 mod format;
 mod run;
 mod state;
 
-use crate::{format::CodeStr, run::run};
-use atty::Stream;
-use byte_unit::Byte;
-use chrono::Local;
-use clap::{App, AppSettings, Arg};
-use env_logger::{fmt::Color, Builder};
-use log::{Level, LevelFilter};
-use regex::RegexSet;
-use std::{
-    env,
-    io::{self, Write},
-    process::exit,
-    str::FromStr,
-    thread::sleep,
-    time::Duration,
+use {
+    crate::{format::CodeStr, run::run},
+    atty::Stream,
+    byte_unit::Byte,
+    chrono::Local,
+    clap::{App, AppSettings, Arg},
+    env_logger::{fmt::Color, Builder},
+    log::{Level, LevelFilter},
+    regex::RegexSet,
+    std::{
+        env,
+        io::{self, Write},
+        process::exit,
+        str::FromStr,
+        thread::sleep,
+        time::Duration,
+    },
 };
 
 #[macro_use]
@@ -28,7 +30,7 @@ extern crate log;
 const VERSION: &str = env!("CARGO_PKG_VERSION");
 
 // Defaults
-const DEFAULT_LOG_LEVEL: LevelFilter = LevelFilter::Info;
+const DEFAULT_LOG_LEVEL: LevelFilter = LevelFilter::Debug;
 const DEFAULT_THRESHOLD: &str = "10 GB";
 
 // Command-line argument and option names
@@ -64,9 +66,12 @@ fn set_up_logging() {
                 Level::Info => {
                     style.set_color(Color::Green);
                 }
-                Level::Debug | Level::Trace => {
+                Level::Debug => {
                     style.set_color(Color::Blue);
                 }
+                Level::Trace => {
+                    style.set_color(Color::Cyan);
+                }
             }
 
             writeln!(
@@ -74,10 +79,10 @@ fn set_up_logging() {
                 "{} {}",
                 style.value(format!(
                     "[{} {}]",
-                    Local::now().format("%Y-%m-%d %H:%M:%S %:z").to_string(),
+                    Local::now().format("%Y-%m-%d %H:%M:%S %:z"),
                     record.level(),
                 )),
-                record.args().to_string(),
+                record.args(),
             )
         })
         .init();
@@ -162,7 +167,7 @@ fn main() {
     let (mut state, mut first_run) = state::load().map_or_else(
         |error| {
             // We couldn't load any state from disk. Log the error.
-            debug!(
+            warn!(
                 "Unable to load state from disk. Proceeding with initial state. Details: {}",
                 error.to_string().code_str(),
             );
