@@ -1,21 +1,23 @@
-use crate::{
-    format::CodeStr,
-    state::{self, State},
-    Settings,
-};
-use byte_unit::Byte;
-use chrono::DateTime;
-use regex::RegexSet;
-use scopeguard::guard;
-use serde::{Deserialize, Serialize};
-use std::{
-    cmp::max,
-    collections::{hash_map::Entry, HashMap, HashSet},
-    io::{self, BufRead, BufReader},
-    mem::drop,
-    ops::Deref,
-    process::{Command, Stdio},
-    time::{Duration, SystemTime, UNIX_EPOCH},
+use {
+    crate::{
+        format::CodeStr,
+        state::{self, State},
+        Settings,
+    },
+    byte_unit::Byte,
+    chrono::DateTime,
+    regex::RegexSet,
+    scopeguard::guard,
+    serde::{Deserialize, Serialize},
+    std::{
+        cmp::max,
+        collections::{hash_map::Entry, HashMap, HashSet},
+        io::{self, BufRead, BufReader},
+        mem::drop,
+        ops::Deref,
+        process::{Command, Stdio},
+        time::{Duration, SystemTime, UNIX_EPOCH},
+    },
 };
 
 // When querying Docker for the image IDs corresponding to a list of container IDs, this is the
@@ -324,7 +326,7 @@ fn space_usage() -> io::Result<Byte> {
         .and_then(|output| {
             for line in output.lines() {
                 // Parse the line as a space record.
-                if let Ok(space_record) = serde_json::from_str::<SpaceRecord>(&line) {
+                if let Ok(space_record) = serde_json::from_str::<SpaceRecord>(line) {
                     // Return early if we found the record we're looking for.
                     if space_record.r#type == "Images" {
                         return Byte::from_str(&space_record.size).map_err(|_| {
@@ -375,12 +377,12 @@ fn delete_image(image: &str) -> io::Result<()> {
 // Update the timestamp for an image.
 fn touch_image(state: &mut State, image_id: &str, verbose: bool) -> io::Result<()> {
     if verbose {
-        info!(
+        debug!(
             "Updating last-used timestamp for image {}\u{2026}",
             image_id.code_str(),
         );
     } else {
-        debug!(
+        trace!(
             "Updating last-used timestamp for image {}\u{2026}",
             image_id.code_str(),
         );
@@ -417,18 +419,17 @@ fn parse_docker_date(timestamp: &str) -> io::Result<Duration> {
 
     // Parse the date and convert it into a duration since the UNIX epoch.
     let duration =
-        match DateTime::parse_from_str(&timestamp_without_timezone_triad, "%Y-%m-%d %H:%M:%S %z") {
+        match DateTime::parse_from_str(timestamp_without_timezone_triad, "%Y-%m-%d %H:%M:%S %z") {
             Ok(datetime) => {
                 datetime.signed_duration_since::<chrono::offset::Utc>(DateTime::from(UNIX_EPOCH))
             }
             Err(error) => return Err(io::Error::new(io::ErrorKind::Other, error)),
         };
 
-    // Convert the duration into a `std::time::Duration`.
-    match duration.to_std() {
-        Ok(duration) => Ok(duration),
-        Err(error) => Err(io::Error::new(io::ErrorKind::Other, error)),
-    }
+    // Convert the duration into a `std::time::Duration`. If the duration is negative, it will be
+    // clamped to zero. This can occur when building images with `kaniko --reproducible`, as the
+    // resulting images have `0001-01-01 00:00:00 +0000 UTC` for their creation timestamp.
+    Ok(duration.to_std().unwrap_or(Duration::ZERO))
 }
 
 // Construct a polyforest of image nodes that reflects their parent-child relationships.
@@ -598,7 +599,7 @@ fn vacuum(
                         repository_tag.repository,
                         repository_tag.tag,
                     )) {
-                        info!(
+                        debug!(
                             "Ignored image {} due to the {} flag.",
                             format!("{}:{}", repository_tag.repository, repository_tag.tag)
                                 .code_str(),
@@ -626,7 +627,7 @@ fn vacuum(
         // Start deleting images, beginning with the least recently used.
         for (image_id, _) in sorted_image_nodes {
             // Delete the image.
-            if let Err(error) = delete_image(&image_id) {
+            if let Err(error) = delete_image(image_id) {
                 // The deletion failed. Just log the error and proceed.
                 error!("{}", error);
             } else {
@@ -646,7 +647,7 @@ fn vacuum(
             }
         }
     } else {
-        info!(
+        debug!(
             "Docker images are using {}, which is within the limit of {}.",
             space.get_appropriate_unit(false).to_string().code_str(),
             threshold.get_appropriate_unit(false).to_string().code_str(),
@@ -678,7 +679,7 @@ pub fn run(settings: &Settings, state: &mut State, first_run: &mut bool) -> io::
 
     // Run the main vacuum logic.
     vacuum(state, *first_run, settings.threshold, &settings.keep)?;
-    state::save(&state)?;
+    state::save(state)?;
     *first_run = false;
 
     // Spawn `docker events --format '{{json .}}'`.
@@ -709,16 +710,16 @@ pub fn run(settings: &Settings, state: &mut State, first_run: &mut bool) -> io::
     for line_option in reader.lines() {
         // Unwrap the line.
         let line = line_option?;
-        debug!("Incoming event: {}", line.code_str());
+        trace!("Incoming event: {}", line.code_str());
 
         // Parse the line as an event.
         let event = match serde_json::from_str::<Event>(&line) {
             Ok(event) => {
-                debug!("Parsed as: {}", format!("{:?}", event).code_str());
+                trace!("Parsed as: {}", format!("{:?}", event).code_str());
                 event
             }
             Err(error) => {
-                debug!("Skipping due to: {}", error);
+                trace!("Skipping due to: {}", error);
                 continue;
             }
         };
@@ -730,7 +731,7 @@ pub fn run(settings: &Settings, state: &mut State, first_run: &mut bool) -> io::
             if let Some(image_name) = event.actor.attributes.image {
                 image_name
             } else {
-                debug!("Invalid Docker event.");
+                trace!("Invalid Docker event.");
                 continue;
             }
         } else if event.r#type == "image"
@@ -743,12 +744,12 @@ pub fn run(settings: &Settings, state: &mut State, first_run: &mut bool) -> io::
         {
             event.id
         } else {
-            debug!("Skipping due to irrelevance.");
+            trace!("Skipping due to irrelevance.");
             continue;
         })?;
 
         // Inform the user that we're about to vacuum.
-        info!("Waking up\u{2026}");
+        debug!("Waking up\u{2026}");
 
         // Update the timestamp for this image.
         touch_image(state, &image_id, true)?;
@@ -757,10 +758,10 @@ pub fn run(settings: &Settings, state: &mut State, first_run: &mut bool) -> io::
         vacuum(state, *first_run, settings.threshold, &settings.keep)?;
 
         // Persist the state.
-        state::save(&state)?;
+        state::save(state)?;
 
         // Inform the user that we're done for now.
-        info!("Going back to sleep\u{2026}");
+        debug!("Going back to sleep\u{2026}");
     }
 
     // The `for` loop above will only terminate if something happened to `docker events`.
@@ -772,14 +773,37 @@ pub fn run(settings: &Settings, state: &mut State, first_run: &mut bool) -> io::
 
 #[cfg(test)]
 mod tests {
-    use super::{construct_polyforest, ImageNode, ImageRecord, RepositoryTag};
-    use crate::state::{self, State};
-    use std::{
-        collections::{HashMap, HashSet},
-        io,
-        time::Duration,
+    use {
+        super::{construct_polyforest, parse_docker_date, ImageNode, ImageRecord, RepositoryTag},
+        crate::state::{self, State},
+        std::{
+            collections::{HashMap, HashSet},
+            io,
+            time::Duration,
+        },
     };
 
+    #[test]
+    fn parse_docker_date_valid() {
+        assert_eq!(
+            parse_docker_date("2022-02-25 12:53:30 -0800 PST").unwrap(),
+            Duration::from_secs(1_645_822_410),
+        );
+    }
+
+    #[test]
+    fn parse_docker_date_before_unix_epoch() {
+        assert_eq!(
+            parse_docker_date("0001-01-01 00:00:00 +0000 UTC").unwrap(),
+            Duration::ZERO,
+        );
+    }
+
+    #[test]
+    fn parse_docker_date_invalid() {
+        assert!(parse_docker_date("invalid").is_err());
+    }
+
     #[test]
     fn construct_polyforest_empty() -> io::Result<()> {
         let state = State {
